Package 'rk.apyramid'

Title: High-performance Age pyramids for Data Frames and Survey objects using SWD principles.
Description: High-performance Age pyramids for Data Frames and Survey objects using SWD principles.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.1.3
Built: 2026-06-04 10:06:07 UTC
Source: https://github.com/AlfCano/rk.apyramid

Help Index